# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [0.1.1] - 2015-11-11
- Exit on --help
- Support Travis CI Pro

## [0.1.0] - 2015-10-27
- Initial release
